# Tradingo

A functional strategy backtesting framework

Integrates with IG platform

## Universe
Defines the list of assets to trade 

### Sampling
## Signals

## Portfolio Construction
## Simulation
## Platform Integration
